==> library1.4.1.tar.bz2: library/seriya/editform.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
  require_once "../utils/chlang.php";

  $title = $TEXT['ser-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
  $button = $TEXT['btn_save'];
  $action = "edit.php";

  if(strlen($_GET['ser_id'])>5) {puterror($result2['skin'],$TEXT['error-ser6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['ser_id'] = rep($_GET['ser_id']);
  
  $old_ser_id = $_GET['ser_id'];

  $query10 = "SELECT * FROM `tbl_seriya` WHERE `ser_id`='".$_GET['ser_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl21']); require_once "../utils/bottom_adm.php"; exit();}
   $result_seriya = mysqli_fetch_array($result10);
    $seriya = $result_seriya['seriya'];
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center">
<tr><td class="inform"><?php echo $TEXT['global-edit']; ?></td><td><input size=30 maxlength=127 type=text name=seriya value='<?php echo $seriya; ?>'></td></tr>
<tr><td></td><td><input class="button2" type=submit value='<?php echo $button; ?>' />
<input type=hidden name=ser_id value='<?php echo $old_ser_id; ?>' />
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/seriya/editform.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
  require_once "../utils/chlang.php";

  $title = $TEXT['ser-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
  $button = $TEXT['btn_save'];
  $action = "edit.php";

  if(strlen($_GET['ser_id'])>5) {puterror($result2['skin'],$TEXT['error-ser6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['ser_id'] = rep($_GET['ser_id']);
  
  $old_ser_id = $_GET['ser_id'];

  $query10 = "SELECT * FROM `tbl_seriya` WHERE `ser_id`='".$_GET['ser_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl21']); require_once "../utils/bottom_adm.php"; exit();}
   $result_seriya = mysqli_fetch_array($result10);
    $seriya = rep_back($result_seriya['seriya']);
?>
<form enctype="multipart/form-data" action="<?php echo $action; ?>" method="post">
<table align="center">
<tr><td class="inform"><?php echo $TEXT['global-edit']; ?></td><td><input size="30" maxlength="127" type="text" name="seriya" value="<?php echo $seriya; ?>" /></td></tr>
<tr><td></td><td><input class="button2" type="submit" value="<?php echo $button; ?>" />
<input type="hidden" name="ser_id" value="<?php echo $old_ser_id; ?>" />
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>
